@@ -212,8 +212,7 @@ pub fn solve(
         (2019, 2, 1) => to_stringer(year2019::day02::part1, input_string),
         (2019, 2, 2) => to_stringer(year2019::day02::part2, input_string),
         (2019, 3, _) => to_stringer_input(year2019::day03::solve, &mut input),
-        (2019, 4, 1) => to_stringer(year2019::day04::part1, input_string),
-        (2019, 4, 2) => to_stringer(year2019::day04::part2, input_string),
+        (2019, 4, _) => to_stringer_input(year2019::day04::solve, &mut input),
         (2019, 5, 1) => to_stringer(year2019::day05::part1, input_string),
         (2019, 5, 2) => to_stringer(year2019::day05::part2, input_string),
         (2019, 6, 1) => to_stringer(year2019::day06::part1, input_string),
